<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="et" sourcelanguage="en_US">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="53"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Automatically save documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Restore window geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Restore live preview state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Open external links in ReText window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Open unknown files in plain text mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Show line numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Tab key inserts spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Tabulation width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Display right margin at column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Icon theme name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Markdown extensions (comma-separated)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Color scheme file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Stylesheet file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="21"/>
        <source>(none)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="28"/>
        <source>Select file to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="32"/>
        <source>Enter locale name (example: en_US)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialogs.py" line="37"/>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="61"/>
        <source>File toolbar</source>
        <translation>Faili tööriistariba</translation>
    </message>
    <message>
        <location filename="window.py" line="63"/>
        <source>Edit toolbar</source>
        <translation>Muuda tööriistariba</translation>
    </message>
    <message>
        <location filename="window.py" line="65"/>
        <source>Search toolbar</source>
        <translation>Otsingu tööriistariba</translation>
    </message>
    <message>
        <location filename="window.py" line="69"/>
        <source>New</source>
        <translation>Uus</translation>
    </message>
    <message>
        <location filename="window.py" line="72"/>
        <source>Open</source>
        <translation>Ava</translation>
    </message>
    <message>
        <location filename="window.py" line="80"/>
        <source>Save</source>
        <translation>Salvesta</translation>
    </message>
    <message>
        <location filename="window.py" line="84"/>
        <source>Save as</source>
        <translation>Salvesta kui...</translation>
    </message>
    <message>
        <location filename="window.py" line="90"/>
        <source>Print</source>
        <translation>Prindi</translation>
    </message>
    <message>
        <location filename="window.py" line="93"/>
        <source>Print preview</source>
        <translation>Printimise eelvaade</translation>
    </message>
    <message>
        <location filename="window.py" line="95"/>
        <source>View HTML code</source>
        <translation>Vaata HTML koodi</translation>
    </message>
    <message>
        <location filename="window.py" line="96"/>
        <source>Change default font</source>
        <translation>Muuda vaikimisi tekstitüüpi</translation>
    </message>
    <message>
        <location filename="window.py" line="97"/>
        <source>Find text</source>
        <translation>Leia tekst</translation>
    </message>
    <message>
        <location filename="window.py" line="101"/>
        <source>Preview</source>
        <translation>Eelvaade</translation>
    </message>
    <message>
        <location filename="window.py" line="110"/>
        <source>Live preview</source>
        <translation>Aktiivne eelvaade</translation>
    </message>
    <message>
        <location filename="window.py" line="114"/>
        <source>Fullscreen mode</source>
        <translation>Täisekraani režiim</translation>
    </message>
    <message>
        <location filename="window.py" line="122"/>
        <source>Quit</source>
        <translation>Välju</translation>
    </message>
    <message>
        <location filename="window.py" line="125"/>
        <source>Undo</source>
        <translation>Võta tagasi</translation>
    </message>
    <message>
        <location filename="window.py" line="127"/>
        <source>Redo</source>
        <translation>Korda</translation>
    </message>
    <message>
        <location filename="window.py" line="129"/>
        <source>Copy</source>
        <translation>Kopeeri</translation>
    </message>
    <message>
        <location filename="window.py" line="131"/>
        <source>Cut</source>
        <translation>Lõika</translation>
    </message>
    <message>
        <location filename="window.py" line="133"/>
        <source>Paste</source>
        <translation>Aseta</translation>
    </message>
    <message>
        <location filename="window.py" line="143"/>
        <source>Enable</source>
        <translation>Luba</translation>
    </message>
    <message>
        <location filename="window.py" line="144"/>
        <source>Set locale</source>
        <translation>Sea regioon</translation>
    </message>
    <message>
        <location filename="window.py" line="145"/>
        <source>Plain text</source>
        <translation>Tavaline tekst</translation>
    </message>
    <message>
        <location filename="window.py" line="146"/>
        <source>Use WebKit renderer</source>
        <translation>Kasuta WebKit renderdajat</translation>
    </message>
    <message>
        <location filename="window.py" line="148"/>
        <source>Generate webpages</source>
        <translation>Tekita veebilehed.</translation>
    </message>
    <message>
        <location filename="window.py" line="149"/>
        <source>Show</source>
        <translation>Näita</translation>
    </message>
    <message>
        <location filename="window.py" line="150"/>
        <source>Next</source>
        <translation>Järgmine</translation>
    </message>
    <message>
        <location filename="window.py" line="152"/>
        <source>Previous</source>
        <translation>Eelmine</translation>
    </message>
    <message>
        <location filename="window.py" line="154"/>
        <source>Get help online</source>
        <translation>Saa abi internetist</translation>
    </message>
    <message>
        <location filename="window.py" line="155"/>
        <source>About %s</source>
        <comment>Example of final string: About ReText</comment>
        <translation>%s kohta</translation>
    </message>
    <message>
        <location filename="window.py" line="159"/>
        <source>About Qt</source>
        <translation>Qt kohta</translation>
    </message>
    <message>
        <location filename="window.py" line="179"/>
        <source>Bold</source>
        <translation>Rasvane</translation>
    </message>
    <message>
        <location filename="window.py" line="181"/>
        <source>Italic</source>
        <translation>Kaldu</translation>
    </message>
    <message>
        <location filename="window.py" line="183"/>
        <source>Underline</source>
        <translation>Allajoonitud</translation>
    </message>
    <message>
        <location filename="window.py" line="191"/>
        <source>Tags</source>
        <translation>Sildid</translation>
    </message>
    <message>
        <location filename="window.py" line="195"/>
        <source>Symbols</source>
        <translation>Sümbolid</translation>
    </message>
    <message>
        <location filename="window.py" line="209"/>
        <source>File</source>
        <translation>Fail</translation>
    </message>
    <message>
        <location filename="window.py" line="210"/>
        <source>Edit</source>
        <translation>Muuda</translation>
    </message>
    <message>
        <location filename="window.py" line="211"/>
        <source>Help</source>
        <translation>Abi</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>Open recent</source>
        <translation>Ava hiljutine</translation>
    </message>
    <message>
        <location filename="window.py" line="217"/>
        <source>Directory</source>
        <translation>Kataloog</translation>
    </message>
    <message>
        <location filename="window.py" line="229"/>
        <source>Export</source>
        <translation>Ekspordi</translation>
    </message>
    <message>
        <location filename="window.py" line="250"/>
        <source>Spell check</source>
        <translation>Õigekirjakontroll</translation>
    </message>
    <message>
        <location filename="window.py" line="261"/>
        <source>Formatting</source>
        <translation>Vormindus</translation>
    </message>
    <message>
        <location filename="window.py" line="299"/>
        <source>Search</source>
        <translation>Otsi</translation>
    </message>
    <message>
        <location filename="window.py" line="301"/>
        <source>Case sensitively</source>
        <translation>Tõstutundeliselt</translation>
    </message>
    <message>
        <location filename="window.py" line="1128"/>
        <source>New document</source>
        <translation>Uus dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="746"/>
        <source>Please, save the file somewhere.</source>
        <translation>Palun salvesta fail kuhugi.</translation>
    </message>
    <message>
        <location filename="window.py" line="735"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Veebilehed salvestatud &lt;code&gt;html&lt;/code&gt; kataloogi.</translation>
    </message>
    <message>
        <location filename="window.py" line="737"/>
        <source>Show directory</source>
        <translation>Näita kataloogi</translation>
    </message>
    <message>
        <location filename="window.py" line="865"/>
        <source>Select one or several files to open</source>
        <translation>Vali avamiseks üks või mitu faili</translation>
    </message>
    <message>
        <location filename="window.py" line="865"/>
        <source>Supported files</source>
        <translation>Toetatud failid</translation>
    </message>
    <message>
        <location filename="window.py" line="865"/>
        <source>All files (*)</source>
        <translation>Kõik failid (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="949"/>
        <source>Plain text (*.txt)</source>
        <translation>Tavaline tekst (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="1027"/>
        <source>Save file</source>
        <translation>Salvesta fail</translation>
    </message>
    <message>
        <location filename="window.py" line="972"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Ei saa faili salvestada, kuna see fail on ainult lugemiseks!</translation>
    </message>
    <message>
        <location filename="window.py" line="1017"/>
        <source>Export document to ODT</source>
        <translation>Ekspordi dokument ODT formaati</translation>
    </message>
    <message>
        <location filename="window.py" line="1017"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument tekstifailid (.*odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="1027"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML failid (*.html, *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="1049"/>
        <source>Export document to PDF</source>
        <translation>Ekspordi dokument PDF&apos;ina</translation>
    </message>
    <message>
        <location filename="window.py" line="1049"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF failid (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="1066"/>
        <source>Print document</source>
        <translation>Prindi dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="1087"/>
        <source>Export document</source>
        <translation>Ekspordi dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="1106"/>
        <source>Failed to execute the command:</source>
        <translation>Järgmise käsu täitmine ebaõnnestus:</translation>
    </message>
    <message>
        <location filename="window.py" line="1187"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dokumenti on muudetud.
Soovid salvestada oma muudatused?</translation>
    </message>
    <message>
        <location filename="window.py" line="1211"/>
        <source>HTML code</source>
        <translation>HTML kood</translation>
    </message>
    <message>
        <location filename="window.py" line="1222"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Lihtne aga võimas Markdown ja reStructuredText redaktor</translation>
    </message>
    <message>
        <location filename="window.py" line="1222"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1222"/>
        <source>Website</source>
        <translation>Veebileht</translation>
    </message>
    <message>
        <location filename="window.py" line="1222"/>
        <source>Markdown syntax</source>
        <translation>Markdown süntaks</translation>
    </message>
    <message>
        <location filename="window.py" line="1222"/>
        <source>reStructuredText syntax</source>
        <translation>reStructuredText süntaks</translation>
    </message>
    <message>
        <location filename="window.py" line="952"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s failid</translation>
    </message>
    <message>
        <location filename="window.py" line="731"/>
        <source>Failed to copy default template, please create template.html manually.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="648"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="258"/>
        <source>Default markup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="574"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="75"/>
        <source>Set encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="924"/>
        <source>Select file encoding from the list:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="78"/>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="86"/>
        <source>Next tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="88"/>
        <source>Previous tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="112"/>
        <source>Table mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
